
# SpiNNakerGraphFrontEnd
An front-end interface for running non-neural applications on SpiNNaker hardware.

Documentation
=============
[SpiNNakerGraphFrontEnd Python documentation](http://spinnakergraphfrontend.readthedocs.io/en/7.3.0)
<br>
[Combined python documentation](http://spinnakermanchester.readthedocs.io/en/7.3.0)

